Enum ucd_parse::CaseStatus
source · pub enum CaseStatus {
Common,
Full,
Simple,
Special,
}Expand description
The status of a particular case mapping.
Variants
Common
Case mappings shared by both “simple” and “full” mappings.
Full
A case mapping that changes the number of codepoints.
Simple
A case mapping that doesn’t change the number of codepoints, when it
differs from Full.
Special
Special cases (currently only for Turkic mappings) that are typically excluded by default. Special cases don’t change the number of codepoints, but may changed the encoding (e.g., UTF-8) length in bytes.
Implementations