pub enum UnicodeDataNumeric {
Integer(i64),
Rational(i64, i64),
}Expand description
A numeric value corresponding to characters with Numeric_Type=Numeric.
A numeric value can either be a signed integer or a rational number.
Variants
Integer(i64)
An integer.
Rational(i64, i64)
A rational number. The first is the numerator and the latter is the denominator.