Types for parsing files in the extracted subdirectory of the Unicode
Character Database download.
These are placed here, rather than at the top level, to help keep the number of types in any given module managable.
Structs
- A single row in the
extracted/DerivedBidiClass.txtfile. - A single row in the
extracted/DerivedBinaryProperties.txtfile. - A single row in the
extracted/DerivedCombiningClass.txtfile. - A single row in the
extracted/DerivedCombiningClass.txtfile. - A single row in the
extracted/DerivedEastAsianWidth.txtfile. - A single row in the
extracted/DerivedGeneralCategory.txtfile. - A single row in the
extracted/DerivedJoiningGroup.txtfile. - A single row in the
extracted/DerivedJoiningType.txtfile. - A single row in the
extracted/DerivedLineBreak.txtfile. - A single row in the
extracted/DerivedName.txtfile. - A single row in the
extracted/DerivedNumericType.txtfile. - A single row in the
extracted/DerivedNumericValues.txtfile.