pub struct CaseFold {
pub codepoint: Codepoint,
pub status: CaseStatus,
pub mapping: Vec<Codepoint>,
}Expand description
A single row in the CaseFolding.txt file.
The contents of CaseFolding.txt are a convenience derived from both
UnicodeData.txt and SpecialCasing.txt.
Note that a single codepoint may be mapped multiple times. In particular,
a single codepoint might have distinct CaseStatus::Simple and
CaseStatus::Full mappings.
Fields
codepoint: CodepointThe codepoint that is being mapped.
status: CaseStatusThe case status of this mapping.
mapping: Vec<Codepoint>The actual case mapping, which is more than one codepoint if this is a “full” mapping.