pub struct Error { /* private fields */ }Expand description
Represents any kind of error that can occur while parsing the UCD.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn line(&self) -> Option<u64>
pub fn line(&self) -> Option<u64>
Return the line number at which this error occurred, if available.
Sourcepub fn path(&self) -> Option<&Path>
pub fn path(&self) -> Option<&Path>
Return the file path associated with this error, if one exists.
Sourcepub fn is_io_error(&self) -> bool
pub fn is_io_error(&self) -> bool
Returns true if and only if this is an I/O error.
If this returns true, the underlying ErrorKind is guaranteed to be
ErrorKind::Io.