Struct ucd_parse::GraphemeClusterBreakTest
source · Expand description
A single row in the auxiliary/GraphemeBreakTest.txt file.
This file defines tests for the grapheme cluster break algorithm.
Fields
grapheme_clusters: Vec<String>Each string is a UTF-8 encoded group of codepoints that make up a single grapheme cluster.
comment: StringA human readable description of this test.