Struct ucd_parse::PropertyValueAlias
source · pub struct PropertyValueAlias {
pub property: String,
pub numeric: Option<u8>,
pub abbreviation: String,
pub long: String,
pub aliases: Vec<String>,
}Expand description
A single row in the PropertyValueAliases.txt file.
Fields
property: StringThe property name for which this value alias applies.
numeric: Option<u8>A numeric abbreviation for this property value, if present. (This is
seemingly only present for the ccc/Canonical_Combining_Class
property.)
abbreviation: StringAn abbreviation for this property value.
long: StringThe “long” form of this property value.
aliases: Vec<String>Additional value aliases (if present).