Struct ucd_parse::SpecialCaseMapping
source · pub struct SpecialCaseMapping {
pub codepoint: Codepoint,
pub lowercase: Vec<Codepoint>,
pub titlecase: Vec<Codepoint>,
pub uppercase: Vec<Codepoint>,
pub conditions: Vec<String>,
}Expand description
A single row in the SpecialCasing.txt file.
Note that a single codepoint may be mapped multiple times. In particular,
a single codepoint might have mappings based on distinct language sensitive
conditions (e.g., U+0307).
Fields
codepoint: CodepointThe codepoint that is being mapped.
lowercase: Vec<Codepoint>The lowercase mapping, which may be empty.
titlecase: Vec<Codepoint>The titlecase mapping, which may be empty.
uppercase: Vec<Codepoint>The uppercase mapping, which may be empty.
conditions: Vec<String>A list of language specific conditions, see SpecialCasing.txt for
more details.