pub struct UnicodeData {Show 15 fields
pub codepoint: Codepoint,
pub name: String,
pub general_category: String,
pub canonical_combining_class: u8,
pub bidi_class: String,
pub decomposition: UnicodeDataDecomposition,
pub numeric_type_decimal: Option<u8>,
pub numeric_type_digit: Option<u8>,
pub numeric_type_numeric: Option<UnicodeDataNumeric>,
pub bidi_mirrored: bool,
pub unicode1_name: String,
pub iso_comment: String,
pub simple_uppercase_mapping: Option<Codepoint>,
pub simple_lowercase_mapping: Option<Codepoint>,
pub simple_titlecase_mapping: Option<Codepoint>,
}Expand description
Represents a single row in the UnicodeData.txt file.
These fields were taken from UAX44, Table 9, as part of the documentation
for the
UnicodeData.txt file.
Fields
codepoint: CodepointThe codepoint corresponding to this row.
name: StringThe name of this codepoint.
general_category: StringThe “general category” of this codepoint.
canonical_combining_class: u8The class of this codepoint used in the Canonical Ordering Algorithm.
Note that some classes map to a particular symbol. See UAX44, Table 15.
bidi_class: StringThe bidirectional class of this codepoint.
Possible values are listed in UAX44, Table 13.
decomposition: UnicodeDataDecompositionThe decomposition mapping for this codepoint. This includes its formatting tag (if present).
numeric_type_decimal: Option<u8>A decimal numeric representation of this codepoint, if it has the
property Numeric_Type=Decimal.
numeric_type_digit: Option<u8>A decimal numeric representation of this codepoint, if it has the
property Numeric_Type=Digit. Note that while this field is still
populated for existing codepoints, no new codepoints will have this
field populated.
numeric_type_numeric: Option<UnicodeDataNumeric>A decimal or rational numeric representation of this codepoint, if it
has the property Numeric_Type=Numeric.
bidi_mirrored: boolA boolean indicating whether this codepoint is “mirrored” in bidirectional text.
unicode1_name: StringThe “old” Unicode 1.0 or ISO 6429 name of this codepoint. Note that
this field is empty unless it is significantly different from
the name field.
iso_comment: StringThe ISO 10464 comment field. This no longer contains any non-NULL values.
simple_uppercase_mapping: Option<Codepoint>This codepoint’s simple uppercase mapping, if it exists.
simple_lowercase_mapping: Option<Codepoint>This codepoint’s simple lowercase mapping, if it exists.
simple_titlecase_mapping: Option<Codepoint>This codepoint’s simple titlecase mapping, if it exists.
Implementations
Sourceimpl UnicodeData
impl UnicodeData
Sourcepub fn is_range_start(&self) -> bool
pub fn is_range_start(&self) -> bool
Returns true if and only if this record corresponds to the start of a range.
Sourcepub fn is_range_end(&self) -> bool
pub fn is_range_end(&self) -> bool
Returns true if and only if this record corresponds to the end of a range.