UnicodeDataDecomposition

Struct UnicodeDataDecomposition 

pub struct UnicodeDataDecomposition {
    pub tag: Option<UnicodeDataDecompositionTag>,
    pub len: usize,
    pub mapping: [Codepoint; 18],
}
Represents a decomposition mapping of a single row in the UnicodeData.txt file.

Fields

tag: Option<UnicodeDataDecompositionTag>

The formatting tag associated with this mapping, if present.

len: usize

The number of codepoints in this mapping.

mapping: [Codepoint; 18]

The codepoints in the mapping. Entries beyond len in the mapping are always U+0000. If no mapping was present, then this always contains a single codepoint corresponding to this row’s character.

Implementations

Source

impl UnicodeDataDecomposition

pub fn new( tag: Option<UnicodeDataDecompositionTag>, mapping: &[Codepoint], ) -> Result<UnicodeDataDecomposition, Error>

Create a new decomposition mapping with the given tag and codepoints.

If there are too many codepoints, then an error is returned.

pub fn push(&mut self, cp: Codepoint) -> Result<(), Error>

Add a new codepoint to this decomposition’s mapping.

If the mapping is already full, then this returns an error.

pub fn mapping(&self) -> &[Codepoint]

Return the mapping as a slice of codepoints. The slice returned has length equivalent to the number of codepoints in this mapping.

pub fn is_canonical(&self) -> bool

Returns true if and only if this decomposition mapping is canonical.