Trait ucd_parse::UcdFile

source ·
pub trait UcdFile: Clone + Debug + Default + Eq + FromStr<Err = Error> + PartialEq {
    fn relative_file_path() -> &'static Path;

    fn file_path<P: AsRef<Path>>(ucd_dir: P) -> PathBuf { ... }
    fn from_dir<P: AsRef<Path>>(
        ucd_dir: P
    ) -> Result<UcdLineParser<File, Self>, Error> { ... } }
Describes a single UCD file.

Required Methods

The file path corresponding to this file, relative to the UCD directory.

Provided Methods

The full file path corresponding to this file given the UCD directory path.

Create an iterator over each record in this UCD file.

The parameter should correspond to the directory containing the UCD.

Implementors